# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import (
    ICollectionElement,
    IConvertibleValueContainer,
    IParameter,
    IParameterSet,
    IPeakList,
    IPSetPeakFind,
    ParameterSet,
)

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.SpectralSummerIntegrator

class IPSetSpectralSummerIntegrator(
    IPSetPeakFind,
    IParameterSet,
    IParameter,
    ICollectionElement,
    System.ICloneable,
    Iterable[Any],
):  # Interface
    BaselineOffsetEnd: float
    BaselineOffsetStart: float
    EndIntegration: float
    EndIntegrationUnitIsMinutes: bool
    FixedBaselineOffset: float
    RTWindowBaselineOffset: float
    SetRTatHighestPointInPeak: bool
    StartIntegration: float
    StartIntegrationUnitIsMinutes: bool
    UseAbsoluteTimes: bool
    UseLowestPointAsBaselineOffset: bool
    UseLowestPointInRTWindowAsBaselineOffset: bool
    UseRelativeDeltasFromRT: bool

class LocalSpectralSummerIntegrator:  # Class
    def __init__(self) -> None: ...
    def FindPeaks(
        self,
        xArray: List[float],
        yArray: List[float],
        useLowestPointAsBaselineOffset: bool,
        fixedBaselineOffset: float,
        useAbsoluteTimes: bool,
        useRelativeDeltasFromRT: bool,
        startIntegration: float,
        endIntegration: float,
        startIntegrationUnitIsMinutes: bool,
        endIntegrationUnitIsMinutes: bool,
        useLowestPointInRTWindowAsBaselineOffset: bool,
        rtWindowBaselineOffset: float,
        setRTatHighestPointInPeak: bool,
    ) -> IPeakList: ...

class PSetSpectralSummerIntegrator(
    ParameterSet,
    IParameter,
    Agilent.MassSpectrometry.DataAnalysis.SpectralSummerIntegrator.IPSetSpectralSummerIntegrator,
    IPSetPeakFind,
    System.ICloneable,
    Iterable[Any],
    IConvertibleValueContainer,
    IParameterSet,
    ICollectionElement,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(
        self,
        source: Agilent.MassSpectrometry.DataAnalysis.SpectralSummerIntegrator.PSetSpectralSummerIntegrator,
    ) -> None: ...

    keyBaselineOffsetEnd: str  # static # readonly
    keyBaselineOffsetStart: str  # static # readonly
    keyEndIntegration: str  # static # readonly
    keyEndIntegrationUnitIsMinutes: str  # static # readonly
    keyFixedBaselineOffset: str  # static # readonly
    keyRTWindowBaselineOffset: str  # static # readonly
    keySetRTatHighestPointInPeak: str  # static # readonly
    keyStartIntegration: str  # static # readonly
    keyStartIntegrationUnitIsMinutes: str  # static # readonly
    keyUseAbsoluteTimes: str  # static # readonly
    keyUseLowestPointAsBaselineOffset: str  # static # readonly
    keyUseLowestPointInRTWindowAsBaselineOffset: str  # static # readonly
    keyUseRelativeDeltasFromRT: str  # static # readonly

    BaselineOffsetEnd: float
    BaselineOffsetStart: float
    EndIntegration: float
    EndIntegrationUnitIsMinutes: bool
    FixedBaselineOffset: float
    RTWindowBaselineOffset: float
    SetRTatHighestPointInPeak: bool
    StartIntegration: float
    StartIntegrationUnitIsMinutes: bool
    UseAbsoluteTimes: bool
    UseLowestPointAsBaselineOffset: bool
    UseLowestPointInRTWindowAsBaselineOffset: bool
    UseRelativeDeltasFromRT: bool



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import GridExportMode, InstrumentType
from .Configuration import ColorScheme
from .Controls2 import IPropertyPage

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Grid

class BandConfig:  # Class
    def __init__(self, name: str) -> None: ...

    Caption: str
    ColumnConfigs: Iterable[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Grid.ColumnConfig
    ]  # readonly
    Hidden: bool
    def __getitem__(
        self, key: str
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.Grid.ColumnConfig: ...
    Name: str  # readonly
    VisibleColumnCount: int  # readonly

    def SetVisibleColumnNames(self, columnNames: Iterable[str]) -> None: ...
    def Contains(self, columnName: str) -> bool: ...
    def Clear(self) -> None: ...
    def SetColumnWidth(self, name: str, width: int) -> None: ...
    @staticmethod
    def CompareColumnsWithVisiblePosition(
        c1: Infragistics.Win.UltraWinGrid.UltraGridColumn,
        c2: Infragistics.Win.UltraWinGrid.UltraGridColumn,
    ) -> int: ...
    def GetVisibleColumnName(self, index: int) -> str: ...
    def GetColumnWidthNames(self) -> Iterable[str]: ...
    def GetColumnWidth(self, name: str) -> int: ...
    def GetColumnCaption(self, columnName: str) -> str: ...
    def CopyFrom(
        self, config: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Grid.BandConfig
    ) -> None: ...
    def ShowColumn(self, columnName: str, columnNameAfter: str) -> None: ...
    def GetVisibleColumnNames(self) -> List[str]: ...
    def CompareColumnOrder(self, c1: str, c2: str) -> int: ...
    def SetDefault(
        self,
        configSectionName: str,
        table: System.Data.DataTable,
        readConfig: bool,
        defaultVisibleColumnsOrder: List[str],
        instrumentType: InstrumentType,
    ) -> None: ...
    def IsColumnVisible(self, column: str) -> bool: ...
    def RemoveColumn(self, columnName: str) -> None: ...
    def ReadFromBand(
        self, band: Infragistics.Win.UltraWinGrid.UltraGridBand
    ) -> None: ...
    def UpdateColumns(
        self,
        gridConfig: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Grid.GridConfigBase,
        band: Infragistics.Win.UltraWinGrid.UltraGridBand,
    ) -> None: ...
    def SaveToConfigFile(self, configSectionName: str) -> None: ...
    def ClearColumnWidths(self) -> None: ...
    def IsColumnHidden(self, column: str) -> bool: ...
    def AddColumn(
        self,
        columnName: str,
        config: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Grid.ColumnConfig,
    ) -> None: ...
    def HideColumn(self, columnName: str) -> None: ...

class ColumnAction:  # Class
    def PerformAction(
        self, cellValue: str, parent: System.Windows.Forms.Control
    ) -> None: ...
    @staticmethod
    def ParseAction(
        action: str,
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.Grid.ColumnAction: ...

class ColumnConfig:  # Class
    def __init__(self, name: str) -> None: ...

    Caption: str
    Hidden: bool  # readonly
    Name: str  # readonly

    def CopyFrom(
        self,
        config: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Grid.ColumnConfig,
    ) -> None: ...
    def SetDefault(
        self, sectionName: str, bandName: str, instrumentType: InstrumentType
    ) -> None: ...

class ColumnsDialog(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(
        self,
        grid: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Grid.GridControlBase,
        masterConfig: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Grid.GridConfigBase,
        bandName: str,
    ) -> None: ...

class ColumnsDialogKeyCaption:  # Class
    def __init__(self, key: str, caption: str) -> None: ...

    Caption: str  # readonly
    Key: str  # readonly

    def GetHashCode(self) -> int: ...
    def ToString(self) -> str: ...
    def Equals(self, obj: Any) -> bool: ...

class GridCellComparer(System.Collections.IComparer):  # Class
    def __init__(self) -> None: ...

    Instance: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Grid.GridCellComparer
    )  # static # readonly

class GridConfigBase(System.IDisposable):  # Class
    def __getitem__(
        self, bandName: str
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.Grid.BandConfig: ...
    ValueListSet: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Grid.ValueListSet
    )  # readonly

    def Contains(self, bandName: str) -> bool: ...
    def ApplyTo(self, grid: Infragistics.Win.UltraWinGrid.UltraGridBase) -> None: ...
    def CopyFrom(
        self,
        config: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Grid.GridConfigBase,
    ) -> None: ...
    def GetTableName(self, dataset: System.Data.DataSet, name: str) -> str: ...
    def InitValueLists(
        self,
        valueLists: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Grid.ValueListSet,
        instrumentType: InstrumentType,
        applicationType: str,
    ) -> None: ...
    def Clear(self) -> None: ...
    def ReadFromGrid(
        self, grid: Infragistics.Win.UltraWinGrid.UltraGridBase
    ) -> None: ...
    def UpdateColumnAttributes(
        self, column: Infragistics.Win.UltraWinGrid.UltraGridColumn
    ) -> None: ...
    def Clone(
        self,
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.Grid.GridConfigBase: ...
    def SetDefault(self, readConfigFile: bool) -> None: ...
    def ReadColumnSettings(self, reader: System.Xml.XmlReader) -> None: ...
    def WriteColumnSettings(self, writer: System.Xml.XmlWriter) -> None: ...
    def Dispose(self) -> None: ...
    def UpdateNumericFormats(
        self, grid: Infragistics.Win.UltraWinGrid.UltraGrid
    ) -> None: ...
    @staticmethod
    def IsNumericType(type: System.Type) -> bool: ...

class GridControlBase(
    Infragistics.Win.IUltraControl,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.Layout.IArrangedElement,
    Infragistics.Win.IUIElementProvider,
    Infragistics.Win.IUltraControlElement,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.ComponentModel.ISupportInitialize,
    Infragistics.Shared.Serialization.ICodeDomSerializable,
    Infragistics.Win.UIAutomation.IProvideUIAutomation,
    System.Windows.Forms.IWin32Window,
    Infragistics.Win.ISupportPresets,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    Infragistics.Win.AppStyling.ISupportAppStyling,
    Infragistics.Win.IControlElementEventProcessor,
    Infragistics.Win.IUIElementTextProvider,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    Infragistics.Win.CalcEngine.IUltraCalcParticipant,
    System.ComponentModel.ISynchronizeInvoke,
    Infragistics.Win.IValidatorClient,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    Agilent.MassHunter.Quantitative.UIModel.IGridControl,
    Infragistics.Win.Touch.ISupportTouchMetrics,
    System.ComponentModel.IComponent,
    Infragistics.Win.ISelectionManager,
    Infragistics.Win.UltraWinGrid.Design.IGridDesignInfo,
    Infragistics.Win.UltraWinGrid.UltraGrid,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
    Infragistics.Win.Touch.IGestureConsumer,
    Infragistics.Shared.IUltraLicensedComponent,
    System.Windows.Forms.IBindableComponent,
    System.IDisposable,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    Infragistics.Win.AutoEditMode.IAutoEditMode,
):  # Class
    def __init__(self) -> None: ...

    AllowMovingColumns: bool
    CanCopy: bool  # readonly
    CanDelete: bool  # readonly
    CanExpandAll: bool  # readonly
    CanPaste: bool  # readonly
    CanPrint: bool  # readonly
    Exporting: bool
    FontSizePercentage: float
    IsHeaderClickSortingEnabled: bool
    IsInEditMode: bool  # readonly
    LastRawBandName: str
    LastRawColumnName: str
    UltraGrid: Infragistics.Win.UltraWinGrid.UltraGrid  # readonly

    def UpdateColors(self) -> None: ...
    def CanUndoInEditMode(self) -> bool: ...
    def FormatColumn(self, rawBandName: str, rawColumnName: str) -> None: ...
    def Sort(self, bandName: str, columnName: str, ascending: bool) -> None: ...
    def DisplayPrintPreview(self) -> None: ...
    def AutoFitColumns(self) -> None: ...
    def CollapseAll(self) -> None: ...
    def IsColumnFormattable(self, rawBandName: str, rawColumnName: str) -> bool: ...
    def GetColumnCaption(self, bandName: str, columnName: str) -> str: ...
    def LoadColumnSettings(self, file: str) -> None: ...
    def GetLogicalColumnName(self, bandName: str, columnName: str) -> str: ...
    def ShowColumn(self, bandName: str, columnName: str, columnAfter: str) -> None: ...
    def UndoInEditMode(self) -> None: ...
    def UpdateRowHeight(self) -> None: ...
    def GetLogicalBandName(self, bandName: str, columnName: str) -> str: ...
    def Copy(self) -> None: ...
    def DisplayColumnChanging(self) -> None: ...
    def ExpandAll(self) -> None: ...
    def SupportsSaveLoadColumnSettings(self) -> bool: ...
    def IsColumnVisible(self, bandName: str, columnName: str) -> bool: ...
    def DisplayColumnChanged(self) -> None: ...
    def PageSetup(self) -> None: ...
    def SaveColumnSettings(self, file: str) -> None: ...
    def Print(self, displayPrintDialog: bool) -> None: ...
    def GetColumnNames(self, bandName: str) -> List[str]: ...
    def Delete(self) -> None: ...
    def ResetColumns(self) -> None: ...
    def ResetSort(self) -> None: ...
    def SetDefaultBehavior(self) -> None: ...
    def HideColumn(self, bandName: str, columnName: str) -> None: ...
    def ShowColumnsDialog(self) -> None: ...
    def Paste(self) -> None: ...

class GridControlDrawFilterBase(Infragistics.Win.IUIElementDrawFilter):  # Class
    def __init__(self) -> None: ...
    def DrawElement(
        self,
        drawPhase: Infragistics.Win.DrawPhase,
        drawParams: Infragistics.Win.UIElementDrawParams,
    ) -> bool: ...
    def GetPhasesToFilter(
        self, drawParams: Infragistics.Win.UIElementDrawParams
    ) -> Infragistics.Win.DrawPhase: ...

class GridExcelExporter(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Grid.GridExporter,
):  # Class
    def __init__(self, file: str) -> None: ...
    def Export(
        self,
        grid: Agilent.MassHunter.Quantitative.UIModel.IGridControl,
        mode: GridExportMode,
    ) -> bool: ...

class GridExporter(System.IDisposable):  # Class
    def Export(
        self,
        grid: Agilent.MassHunter.Quantitative.UIModel.IGridControl,
        mode: GridExportMode,
    ) -> bool: ...
    def Dispose(self) -> None: ...

class GridTextExporter(
    System.IDisposable,
    Infragistics.Win.UltraWinGrid.IUltraGridExporter,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Grid.GridTextExporterBase,
):  # Class
    def __init__(self, writer: System.IO.TextWriter, delimiter: str) -> None: ...

class GridTextExporterBase(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Grid.GridExporter,
    Infragistics.Win.UltraWinGrid.IUltraGridExporter,
):  # Class
    def Export(
        self,
        grid: Agilent.MassHunter.Quantitative.UIModel.IGridControl,
        mode: GridExportMode,
    ) -> bool: ...
    def EndExport(self, canceled: bool) -> None: ...
    def BeginExport(
        self,
        exportLayout: Infragistics.Win.UltraWinGrid.UltraGridLayout,
        rows: Infragistics.Win.UltraWinGrid.RowsCollection,
    ) -> None: ...
    def ProcessRow(
        self,
        row: Infragistics.Win.UltraWinGrid.UltraGridRow,
        processRowParams: Infragistics.Win.UltraWinGrid.ProcessRowParams,
    ) -> None: ...

class GridXmlExporter(
    System.IDisposable,
    Infragistics.Win.UltraWinGrid.IUltraGridExporter,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Grid.GridTextExporterBase,
):  # Class
    def __init__(self, writer: System.Xml.XmlWriter, rootElement: str) -> None: ...

class IPlottableColumn(
    Agilent.MassHunter.Quantitative.UIModel.IPlottableColumn
):  # Interface
    ...

class IPlottableGrid(
    Agilent.MassHunter.Quantitative.UIModel.IPlottableGrid
):  # Interface
    ...

class IntegrationParametersPropertyDescriptor(
    System.ComponentModel.PropertyDescriptor
):  # Class
    def __init__(
        self, baseDescriptor: System.ComponentModel.PropertyDescriptor
    ) -> None: ...

    ComponentType: System.Type  # readonly
    IsReadOnly: bool  # readonly
    PropertyType: System.Type  # readonly

    @staticmethod
    def ConvertValue(value_: Any) -> Any: ...
    def GetValue(self, component: Any) -> Any: ...
    def CanResetValue(self, component: Any) -> bool: ...
    def SetValue(self, component: Any, value_: Any) -> None: ...
    def ShouldSerializeValue(self, component: Any) -> bool: ...
    def ResetValue(self, component: Any) -> None: ...

class NotFoundValue:  # Class
    Instance: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Grid.NotFoundValue
    )  # static # readonly

    def ToString(self) -> str: ...

class PropertyPage(
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UserControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    IPropertyPage,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.IWin32Window,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(
        self,
        grid: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Grid.GridControlBase,
        applicationType: str,
    ) -> None: ...

    DisplayName: str
    IsDirty: bool  # readonly
    SelectedColorScheme: ColorScheme  # readonly

    def Initialize(
        self,
        grid: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Grid.GridControlBase,
        applicationType: str,
    ) -> None: ...
    def SetActive(self) -> None: ...
    def DoDefault(self) -> None: ...
    def Apply(self) -> None: ...

    ColorSchemeChanged: System.EventHandler  # Event
    PageChanged: System.EventHandler  # Event

class UrlColumnAction(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Grid.ColumnAction
):  # Class
    def PerformAction(
        self, cellValue: str, parent: System.Windows.Forms.Control
    ) -> None: ...

class ValueListSet(System.IDisposable):  # Class
    def __init__(self) -> None: ...
    def Contains(self, table: str, column: str) -> bool: ...
    @overload
    def Add(
        self, table: str, column: str, valueList: Infragistics.Win.ValueList
    ) -> None: ...
    @overload
    def Add(
        self,
        table: str,
        column: str,
        valueList: Infragistics.Win.ValueList,
        style: Infragistics.Win.UltraWinGrid.ColumnStyle,
    ) -> None: ...
    def SetColumnStyle(
        self, table: str, column: str, style: Infragistics.Win.UltraWinGrid.ColumnStyle
    ) -> None: ...
    def GetValueList(self, table: str, column: str) -> Infragistics.Win.ValueList: ...
    def GetColumnStyle(
        self, table: str, column: str
    ) -> Infragistics.Win.UltraWinGrid.ColumnStyle: ...
    def Dispose(self) -> None: ...

class XmlContentPropertyDescriptor(System.ComponentModel.PropertyDescriptor):  # Class
    def __init__(
        self, baseDescriptor: System.ComponentModel.PropertyDescriptor
    ) -> None: ...

    ComponentType: System.Type  # readonly
    IsReadOnly: bool  # readonly
    PropertyType: System.Type  # readonly

    @staticmethod
    def ConvertValue(value_: Any) -> Any: ...
    def GetValue(self, component: Any) -> Any: ...
    def CanResetValue(self, component: Any) -> bool: ...
    def SetValue(self, component: Any, value_: Any) -> None: ...
    def ShouldSerializeValue(self, component: Any) -> bool: ...
    def ResetValue(self, component: Any) -> None: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Discovered Generic TypeVars:
T = TypeVar("T")
from .DataAnalysis import IConsistency, IRange, IReadOnlyObject, IUnitsAndPrecision

# Stubs for namespace: Agilent.MassSpectrometry.MIDAC

class AbundanceMeasure(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    Average: Agilent.MassSpectrometry.MIDAC.AbundanceMeasure = ...  # static # readonly
    Max: Agilent.MassSpectrometry.MIDAC.AbundanceMeasure = ...  # static # readonly
    Sum: Agilent.MassSpectrometry.MIDAC.AbundanceMeasure = ...  # static # readonly
    Unspecified: Agilent.MassSpectrometry.MIDAC.AbundanceMeasure = (
        ...
    )  # static # readonly

class ApplicableFilters(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    AcqTimeRange: Agilent.MassSpectrometry.MIDAC.ApplicableFilters = (
        ...
    )  # static # readonly
    CompensationField: Agilent.MassSpectrometry.MIDAC.ApplicableFilters = (
        ...
    )  # static # readonly
    DispersionField: Agilent.MassSpectrometry.MIDAC.ApplicableFilters = (
        ...
    )  # static # readonly
    DriftTimeRange: Agilent.MassSpectrometry.MIDAC.ApplicableFilters = (
        ...
    )  # static # readonly
    FragmentationClass: Agilent.MassSpectrometry.MIDAC.ApplicableFilters = (
        ...
    )  # static # readonly
    FragmentationEnergy: Agilent.MassSpectrometry.MIDAC.ApplicableFilters = (
        ...
    )  # static # readonly
    FragmentationOpMode: Agilent.MassSpectrometry.MIDAC.ApplicableFilters = (
        ...
    )  # static # readonly
    FragmentorVoltage: Agilent.MassSpectrometry.MIDAC.ApplicableFilters = (
        ...
    )  # static # readonly
    IonPolarity: Agilent.MassSpectrometry.MIDAC.ApplicableFilters = (
        ...
    )  # static # readonly
    IonizationMode: Agilent.MassSpectrometry.MIDAC.ApplicableFilters = (
        ...
    )  # static # readonly
    MsLevel: Agilent.MassSpectrometry.MIDAC.ApplicableFilters = ...  # static # readonly
    MsScanType: Agilent.MassSpectrometry.MIDAC.ApplicableFilters = (
        ...
    )  # static # readonly
    MzExclusionRange: Agilent.MassSpectrometry.MIDAC.ApplicableFilters = (
        ...
    )  # static # readonly
    MzInclusionRange: Agilent.MassSpectrometry.MIDAC.ApplicableFilters = (
        ...
    )  # static # readonly
    MzOfInterest: Agilent.MassSpectrometry.MIDAC.ApplicableFilters = (
        ...
    )  # static # readonly
    ScanSegmentRange: Agilent.MassSpectrometry.MIDAC.ApplicableFilters = (
        ...
    )  # static # readonly
    Unspecified: Agilent.MassSpectrometry.MIDAC.ApplicableFilters = (
        ...
    )  # static # readonly

class CenterRange(
    Agilent.MassSpectrometry.MIDAC.Range[T],
    Generic[T],
    System.ICloneable,
    Agilent.MassSpectrometry.MIDAC.IRange[T],
    Agilent.MassSpectrometry.MIDAC.ICenterRange[T],
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, zeroWidthValue: T) -> None: ...
    @overload
    def __init__(
        self,
        center: T,
        min: T,
        max: T,
        units: Agilent.MassSpectrometry.MIDAC.MidacUnits,
    ) -> None: ...
    @overload
    def __init__(self, src: Agilent.MassSpectrometry.MIDAC.CenterRange) -> None: ...

class ChromatogramType(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    BasePeak: Agilent.MassSpectrometry.MIDAC.ChromatogramType = ...  # static # readonly
    ExtractedCompound: Agilent.MassSpectrometry.MIDAC.ChromatogramType = (
        ...
    )  # static # readonly
    ExtractedIon: Agilent.MassSpectrometry.MIDAC.ChromatogramType = (
        ...
    )  # static # readonly
    ExtractedWavelength: Agilent.MassSpectrometry.MIDAC.ChromatogramType = (
        ...
    )  # static # readonly
    InstrumentParameter: Agilent.MassSpectrometry.MIDAC.ChromatogramType = (
        ...
    )  # static # readonly
    MultipleReactionMode: Agilent.MassSpectrometry.MIDAC.ChromatogramType = (
        ...
    )  # static # readonly
    NeutralLoss: Agilent.MassSpectrometry.MIDAC.ChromatogramType = (
        ...
    )  # static # readonly
    SelectedIonMonitoring: Agilent.MassSpectrometry.MIDAC.ChromatogramType = (
        ...
    )  # static # readonly
    Signal: Agilent.MassSpectrometry.MIDAC.ChromatogramType = ...  # static # readonly
    TotalCompound: Agilent.MassSpectrometry.MIDAC.ChromatogramType = (
        ...
    )  # static # readonly
    TotalIon: Agilent.MassSpectrometry.MIDAC.ChromatogramType = ...  # static # readonly
    TotalWavelength: Agilent.MassSpectrometry.MIDAC.ChromatogramType = (
        ...
    )  # static # readonly
    Unspecified: Agilent.MassSpectrometry.MIDAC.ChromatogramType = (
        ...
    )  # static # readonly

class DevType(System.IConvertible, System.IComparable, System.IFormattable):  # Struct
    ALS: Agilent.MassSpectrometry.MIDAC.DevType = ...  # static # readonly
    AnalogDigitalConverter: Agilent.MassSpectrometry.MIDAC.DevType = (
        ...
    )  # static # readonly
    BinaryPump: Agilent.MassSpectrometry.MIDAC.DevType = ...  # static # readonly
    CANValves: Agilent.MassSpectrometry.MIDAC.DevType = ...  # static # readonly
    CE: Agilent.MassSpectrometry.MIDAC.DevType = ...  # static # readonly
    CTC: Agilent.MassSpectrometry.MIDAC.DevType = ...  # static # readonly
    CapillaryPump: Agilent.MassSpectrometry.MIDAC.DevType = ...  # static # readonly
    ChipCube: Agilent.MassSpectrometry.MIDAC.DevType = ...  # static # readonly
    ColumnCompCluster: Agilent.MassSpectrometry.MIDAC.DevType = ...  # static # readonly
    CompactLC1220DAD: Agilent.MassSpectrometry.MIDAC.DevType = ...  # static # readonly
    CompactLC1220GradPump: Agilent.MassSpectrometry.MIDAC.DevType = (
        ...
    )  # static # readonly
    CompactLC1220IsoPump: Agilent.MassSpectrometry.MIDAC.DevType = (
        ...
    )  # static # readonly
    CompactLC1220Sampler: Agilent.MassSpectrometry.MIDAC.DevType = (
        ...
    )  # static # readonly
    CompactLC1220VWD: Agilent.MassSpectrometry.MIDAC.DevType = ...  # static # readonly
    CompactLCColumnOven: Agilent.MassSpectrometry.MIDAC.DevType = (
        ...
    )  # static # readonly
    CompactLCGradPump: Agilent.MassSpectrometry.MIDAC.DevType = ...  # static # readonly
    CompactLCIsoPump: Agilent.MassSpectrometry.MIDAC.DevType = ...  # static # readonly
    CompactLCSampler: Agilent.MassSpectrometry.MIDAC.DevType = ...  # static # readonly
    CompactLCVWD: Agilent.MassSpectrometry.MIDAC.DevType = ...  # static # readonly
    DiodeArrayDetector: Agilent.MassSpectrometry.MIDAC.DevType = (
        ...
    )  # static # readonly
    ElectronCaptureDetector: Agilent.MassSpectrometry.MIDAC.DevType = (
        ...
    )  # static # readonly
    EvaporativeLightScatteringDetector: Agilent.MassSpectrometry.MIDAC.DevType = (
        ...
    )  # static # readonly
    FlameIonizationDetector: Agilent.MassSpectrometry.MIDAC.DevType = (
        ...
    )  # static # readonly
    FlexCube: Agilent.MassSpectrometry.MIDAC.DevType = ...  # static # readonly
    FluorescenceDetector: Agilent.MassSpectrometry.MIDAC.DevType = (
        ...
    )  # static # readonly
    GCDetector: Agilent.MassSpectrometry.MIDAC.DevType = ...  # static # readonly
    HDR: Agilent.MassSpectrometry.MIDAC.DevType = ...  # static # readonly
    IonTrap: Agilent.MassSpectrometry.MIDAC.DevType = ...  # static # readonly
    IsocraticPump: Agilent.MassSpectrometry.MIDAC.DevType = ...  # static # readonly
    LowFlowPump: Agilent.MassSpectrometry.MIDAC.DevType = ...  # static # readonly
    MicroWellPlateSampler: Agilent.MassSpectrometry.MIDAC.DevType = (
        ...
    )  # static # readonly
    Mixed: Agilent.MassSpectrometry.MIDAC.DevType = ...  # static # readonly
    MultiWavelengthDetector: Agilent.MassSpectrometry.MIDAC.DevType = (
        ...
    )  # static # readonly
    NanoPump: Agilent.MassSpectrometry.MIDAC.DevType = ...  # static # readonly
    PumpValveCluster: Agilent.MassSpectrometry.MIDAC.DevType = ...  # static # readonly
    Quadrupole: Agilent.MassSpectrometry.MIDAC.DevType = ...  # static # readonly
    QuadrupoleTimeOfFlight: Agilent.MassSpectrometry.MIDAC.DevType = (
        ...
    )  # static # readonly
    QuaternaryPump: Agilent.MassSpectrometry.MIDAC.DevType = ...  # static # readonly
    RefractiveIndexDetector: Agilent.MassSpectrometry.MIDAC.DevType = (
        ...
    )  # static # readonly
    SFC: Agilent.MassSpectrometry.MIDAC.DevType = ...  # static # readonly
    TandemQuadrupole: Agilent.MassSpectrometry.MIDAC.DevType = ...  # static # readonly
    ThermalConductivityDetector: Agilent.MassSpectrometry.MIDAC.DevType = (
        ...
    )  # static # readonly
    ThermostattedColumnCompartment: Agilent.MassSpectrometry.MIDAC.DevType = (
        ...
    )  # static # readonly
    TimeOfFlight: Agilent.MassSpectrometry.MIDAC.DevType = ...  # static # readonly
    UIB2: Agilent.MassSpectrometry.MIDAC.DevType = ...  # static # readonly
    Unknown: Agilent.MassSpectrometry.MIDAC.DevType = ...  # static # readonly
    VariableWavelengthDetector: Agilent.MassSpectrometry.MIDAC.DevType = (
        ...
    )  # static # readonly
    WellPlateSampler: Agilent.MassSpectrometry.MIDAC.DevType = ...  # static # readonly

class DoubleCwRange(
    Agilent.MassSpectrometry.MIDAC.IDoubleRange,
    Agilent.MassSpectrometry.MIDAC.IRange[float],
    System.ICloneable,
    Agilent.MassSpectrometry.MIDAC.ICenterRange[float],
    Agilent.MassSpectrometry.MIDAC.IDoubleCenterRange,
    Agilent.MassSpectrometry.MIDAC.CenterRange[float],
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, center: float) -> None: ...
    @overload
    def __init__(self, center: float, min: float, max: float) -> None: ...
    @overload
    def __init__(
        self,
        center: float,
        min: float,
        max: float,
        units: Agilent.MassSpectrometry.MIDAC.MidacUnits,
    ) -> None: ...
    @overload
    def __init__(self, src: Agilent.MassSpectrometry.MIDAC.DoubleCwRange) -> None: ...

class DoubleRange(
    Agilent.MassSpectrometry.MIDAC.IRange[float],
    IRange,
    IReadOnlyObject,
    IConsistency,
    Agilent.MassSpectrometry.MIDAC.Range[float],
    IUnitsAndPrecision,
    System.ICloneable,
    Agilent.MassSpectrometry.MIDAC.IDoubleRange,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, zeroWidthValue: float) -> None: ...
    @overload
    def __init__(self, min: float, max: float) -> None: ...
    @overload
    def __init__(
        self, min: float, max: float, units: Agilent.MassSpectrometry.MIDAC.MidacUnits
    ) -> None: ...
    @overload
    def __init__(self, src: Agilent.MassSpectrometry.MIDAC.DoubleRange) -> None: ...
    @overload
    def __init__(self, src: Agilent.MassSpectrometry.MIDAC.IDoubleRange) -> None: ...
    @staticmethod
    def EqualRanges(
        rng1: Agilent.MassSpectrometry.MIDAC.IDoubleRange,
        rng2: Agilent.MassSpectrometry.MIDAC.IDoubleRange,
    ) -> bool: ...
    @staticmethod
    def EqualRangeArrays(
        da1: List[Agilent.MassSpectrometry.MIDAC.IDoubleRange],
        da2: List[Agilent.MassSpectrometry.MIDAC.IDoubleRange],
    ) -> bool: ...
    @staticmethod
    def IsNullOrEmpty(range: Agilent.MassSpectrometry.MIDAC.IDoubleRange) -> bool: ...

class FragmentationClass(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    HighEnergy: Agilent.MassSpectrometry.MIDAC.FragmentationClass = (
        ...
    )  # static # readonly
    LowEnergy: Agilent.MassSpectrometry.MIDAC.FragmentationClass = (
        ...
    )  # static # readonly
    Mixed: Agilent.MassSpectrometry.MIDAC.FragmentationClass = ...  # static # readonly
    Unspecified: Agilent.MassSpectrometry.MIDAC.FragmentationClass = (
        ...
    )  # static # readonly

class FragmentationOpMode(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    HiLoFrag: Agilent.MassSpectrometry.MIDAC.FragmentationOpMode = (
        ...
    )  # static # readonly
    NonSelective: Agilent.MassSpectrometry.MIDAC.FragmentationOpMode = (
        ...
    )  # static # readonly
    Selective: Agilent.MassSpectrometry.MIDAC.FragmentationOpMode = (
        ...
    )  # static # readonly
    Unspecified: Agilent.MassSpectrometry.MIDAC.FragmentationOpMode = (
        ...
    )  # static # readonly

class ICenterRange(
    Agilent.MassSpectrometry.MIDAC.IRange[T], System.ICloneable
):  # Interface
    Width: T  # readonly
    WidthPct: T  # readonly
    WidthPpm: T  # readonly

    def SetCenterWidthPpm(self, center: T, widthPpm: T) -> None: ...
    def SetCenterDeltas(self, center: T, deltaLow: T, deltaHigh: T) -> None: ...
    def GetHalfWidths(self, lower: T, upper: T) -> None: ...
    def Clone(self) -> Agilent.MassSpectrometry.MIDAC.ICenterRange: ...
    def SetCenterWidthPct(self, center: T, widthPct: T) -> None: ...
    def SetCenterWidth(self, center: T, width: T) -> None: ...

class IDoubleCenterRange(
    Agilent.MassSpectrometry.MIDAC.ICenterRange[float],
    Agilent.MassSpectrometry.MIDAC.IRange[float],
    System.ICloneable,
    Agilent.MassSpectrometry.MIDAC.IDoubleRange,
):  # Interface
    def Clone(self) -> Agilent.MassSpectrometry.MIDAC.IDoubleCenterRange: ...

class IDoubleRange(
    Agilent.MassSpectrometry.MIDAC.IRange[float], System.ICloneable
):  # Interface
    def Clone(self) -> Agilent.MassSpectrometry.MIDAC.IDoubleRange: ...

class IIntRange(
    Agilent.MassSpectrometry.MIDAC.IRange[int], System.ICloneable
):  # Interface
    def Clone(self) -> Agilent.MassSpectrometry.MIDAC.IIntRange: ...

class IMidacChromDataMs(object):  # Interface
    ChromatogramType: Agilent.MassSpectrometry.MIDAC.ChromatogramType  # readonly
    CompensationFieldRange: Agilent.MassSpectrometry.MIDAC.IDoubleRange  # readonly
    DispersionFieldRange: Agilent.MassSpectrometry.MIDAC.IDoubleRange  # readonly
    DriftTimeRanges: List[Agilent.MassSpectrometry.MIDAC.IDoubleRange]  # readonly
    FragmentationClass: Agilent.MassSpectrometry.MIDAC.FragmentationClass  # readonly
    FragmentationEnergyRange: Agilent.MassSpectrometry.MIDAC.IDoubleRange  # readonly
    FragmentationOpMode: Agilent.MassSpectrometry.MIDAC.FragmentationOpMode  # readonly
    FragmentorVoltageRange: Agilent.MassSpectrometry.MIDAC.IDoubleRange  # readonly
    IonPolarity: Agilent.MassSpectrometry.MIDAC.Polarity  # readonly
    IonizationMode: Agilent.MassSpectrometry.MIDAC.Ionization  # readonly
    IsCycleSummed: bool  # readonly
    MsLevel: Agilent.MassSpectrometry.MIDAC.MsLevel  # readonly
    MzExclusionRanges: List[Agilent.MassSpectrometry.MIDAC.IDoubleRange]  # readonly
    MzInclusionRanges: List[Agilent.MassSpectrometry.MIDAC.IDoubleRange]  # readonly
    MzOfInterestRanges: List[Agilent.MassSpectrometry.MIDAC.IDoubleRange]  # readonly
    ScanSegmentRange: Agilent.MassSpectrometry.MIDAC.IIntRange  # readonly
    XArray: List[float]  # readonly
    XUnit: Agilent.MassSpectrometry.MIDAC.MidacUnits  # readonly
    YArray: List[float]  # readonly

class IMidacDeviceInfo(object):  # Interface
    DeviceName: str  # readonly
    DeviceType: Agilent.MassSpectrometry.MIDAC.DevType  # readonly
    OrdinalNumber: int  # readonly

    def Clone(self) -> Agilent.MassSpectrometry.MIDAC.IMidacDeviceInfo: ...

class IMidacFileInfo(object):  # Interface
    AcquisitionDate: System.DateTime  # readonly
    AcquisitionIsComplete: bool  # readonly
    AcquisitionSofwareVersion: str  # readonly
    FilePath: str  # readonly
    FileUnitConverter: Agilent.MassSpectrometry.MIDAC.IMidacUnitConverter  # readonly
    HasHiLoFragData: bool  # readonly
    InstrumentName: str  # readonly
    MaxAcqTime: float  # readonly
    MaxFlightTimeBin: int  # readonly
    MaxNonTfsMsPerFrame: int  # readonly
    NumFrames: int  # readonly
    TfsMsDetails: Agilent.MassSpectrometry.MIDAC.IMidacMsDetailsSpec  # readonly

    def Clone(self) -> Agilent.MassSpectrometry.MIDAC.IMidacFileInfo: ...

class IMidacFrameInfo(object):  # Interface
    AbundRange: Agilent.MassSpectrometry.MIDAC.IDoubleRange  # readonly
    AcqTimeRange: Agilent.MassSpectrometry.MIDAC.IDoubleRange  # readonly
    DriftBinRange: Agilent.MassSpectrometry.MIDAC.IIntRange  # readonly
    DriftField: float  # readonly
    DriftPressure: float  # readonly
    DriftTemperature: float  # readonly
    DriftTimeRange: Agilent.MassSpectrometry.MIDAC.IDoubleRange  # readonly
    FileInfo: Agilent.MassSpectrometry.MIDAC.IMidacFileInfo  # readonly
    FrameNumRange: Agilent.MassSpectrometry.MIDAC.IIntRange  # readonly
    FrameUnitConverter: Agilent.MassSpectrometry.MIDAC.IMidacUnitConverter  # readonly
    MzRange: Agilent.MassSpectrometry.MIDAC.IDoubleRange  # readonly
    NumTransients: int  # readonly
    SpectrumDetails: Agilent.MassSpectrometry.MIDAC.IMidacMsDetailsSpec  # readonly
    Tic: float  # readonly
    TimeSegmentId: int  # readonly
    TofBinRange: Agilent.MassSpectrometry.MIDAC.IIntRange  # readonly

    def Clone(self) -> Agilent.MassSpectrometry.MIDAC.IMidacFrameInfo: ...

class IMidacMsDetails(object):  # Interface
    AcqTimeRange: Agilent.MassSpectrometry.MIDAC.IDoubleRange
    AcqTimeRanges: List[Agilent.MassSpectrometry.MIDAC.IDoubleRange]
    CompensationFieldRange: Agilent.MassSpectrometry.MIDAC.IDoubleRange
    DispersionFieldRange: Agilent.MassSpectrometry.MIDAC.IDoubleRange
    DriftTimeRanges: List[Agilent.MassSpectrometry.MIDAC.IDoubleRange]
    FragmentationClass: Agilent.MassSpectrometry.MIDAC.FragmentationClass
    FragmentationEnergyRange: Agilent.MassSpectrometry.MIDAC.IDoubleRange
    FragmentationOpMode: Agilent.MassSpectrometry.MIDAC.FragmentationOpMode
    FragmentorVoltageRange: Agilent.MassSpectrometry.MIDAC.IDoubleRange
    IonPolarity: Agilent.MassSpectrometry.MIDAC.Polarity
    IonizationMode: Agilent.MassSpectrometry.MIDAC.Ionization
    MsLevel: Agilent.MassSpectrometry.MIDAC.MsLevel
    MsScanType: Agilent.MassSpectrometry.MIDAC.MsScanType
    MsStorageMode: Agilent.MassSpectrometry.MIDAC.MsStorageMode
    MzExclusionRanges: List[Agilent.MassSpectrometry.MIDAC.IDoubleRange]
    MzInclusionRanges: List[Agilent.MassSpectrometry.MIDAC.IDoubleRange]
    MzOfInterestRanges: List[Agilent.MassSpectrometry.MIDAC.IDoubleRange]
    ScanSegmentRange: Agilent.MassSpectrometry.MIDAC.IIntRange

    def Clear(self) -> None: ...
    def Clone(self) -> Agilent.MassSpectrometry.MIDAC.IMidacMsDetails: ...

class IMidacMsDetailsChrom(object):  # Interface
    AcqTimeRange: Agilent.MassSpectrometry.MIDAC.IDoubleRange
    CompensationFieldRange: Agilent.MassSpectrometry.MIDAC.IDoubleRange
    DispersionFieldRange: Agilent.MassSpectrometry.MIDAC.IDoubleRange
    DriftTimeRanges: List[Agilent.MassSpectrometry.MIDAC.IDoubleRange]
    FragmentationClass: Agilent.MassSpectrometry.MIDAC.FragmentationClass
    FragmentationEnergyRange: Agilent.MassSpectrometry.MIDAC.IDoubleRange
    FragmentationOpMode: Agilent.MassSpectrometry.MIDAC.FragmentationOpMode
    FragmentorVoltageRange: Agilent.MassSpectrometry.MIDAC.IDoubleRange
    IonPolarity: Agilent.MassSpectrometry.MIDAC.Polarity
    IonizationMode: Agilent.MassSpectrometry.MIDAC.Ionization
    MsLevel: Agilent.MassSpectrometry.MIDAC.MsLevel
    MsScanType: Agilent.MassSpectrometry.MIDAC.MsScanType
    MsStorageMode: Agilent.MassSpectrometry.MIDAC.MsStorageMode
    MzExclusionRanges: List[Agilent.MassSpectrometry.MIDAC.IDoubleRange]
    MzInclusionRanges: List[Agilent.MassSpectrometry.MIDAC.IDoubleRange]
    MzOfInterestRanges: List[Agilent.MassSpectrometry.MIDAC.IDoubleRange]
    ScanSegmentRange: Agilent.MassSpectrometry.MIDAC.IIntRange

    def Clone(self) -> Agilent.MassSpectrometry.MIDAC.IMidacMsDetailsChrom: ...

class IMidacMsDetailsSpec(object):  # Interface
    AbundanceLimit: float
    AcqTimeRanges: List[Agilent.MassSpectrometry.MIDAC.IDoubleRange]
    CompensationFieldRange: Agilent.MassSpectrometry.MIDAC.IDoubleRange
    DispersionFieldRange: Agilent.MassSpectrometry.MIDAC.IDoubleRange
    DriftTimeRanges: List[Agilent.MassSpectrometry.MIDAC.IDoubleRange]
    FragmentationClass: Agilent.MassSpectrometry.MIDAC.FragmentationClass
    FragmentationEnergyRange: Agilent.MassSpectrometry.MIDAC.IDoubleRange
    FragmentationOpMode: Agilent.MassSpectrometry.MIDAC.FragmentationOpMode
    FragmentorVoltageRange: Agilent.MassSpectrometry.MIDAC.IDoubleRange
    IonPolarity: Agilent.MassSpectrometry.MIDAC.Polarity
    IonizationMode: Agilent.MassSpectrometry.MIDAC.Ionization
    MsLevel: Agilent.MassSpectrometry.MIDAC.MsLevel
    MsScanType: Agilent.MassSpectrometry.MIDAC.MsScanType
    MsStorageMode: Agilent.MassSpectrometry.MIDAC.MsStorageMode
    MzOfInterestRanges: List[Agilent.MassSpectrometry.MIDAC.IDoubleRange]
    TofBinWidth: float

    def Clone(self) -> Agilent.MassSpectrometry.MIDAC.IMidacMsDetailsSpec: ...

class IMidacMsFilters(object):  # Interface
    AcqTimeRange: Agilent.MassSpectrometry.MIDAC.IDoubleRange
    AcqTimeRanges: List[Agilent.MassSpectrometry.MIDAC.IDoubleRange]
    ApplicableFilters: Agilent.MassSpectrometry.MIDAC.ApplicableFilters
    CompensationFieldRange: Agilent.MassSpectrometry.MIDAC.IDoubleRange
    DispersionFieldRange: Agilent.MassSpectrometry.MIDAC.IDoubleRange
    DriftTimeRanges: List[Agilent.MassSpectrometry.MIDAC.IDoubleRange]
    FragmentationClass: Agilent.MassSpectrometry.MIDAC.FragmentationClass
    FragmentationEnergyRange: Agilent.MassSpectrometry.MIDAC.IDoubleRange
    FragmentationOpMode: Agilent.MassSpectrometry.MIDAC.FragmentationOpMode
    FragmentorVoltageRange: Agilent.MassSpectrometry.MIDAC.IDoubleRange
    IonPolarity: Agilent.MassSpectrometry.MIDAC.Polarity
    IonizationMode: Agilent.MassSpectrometry.MIDAC.Ionization
    MsLevel: Agilent.MassSpectrometry.MIDAC.MsLevel
    MsScanType: Agilent.MassSpectrometry.MIDAC.MsScanType
    MsStorageMode: Agilent.MassSpectrometry.MIDAC.MsStorageMode
    MzExclusionRanges: List[Agilent.MassSpectrometry.MIDAC.IDoubleRange]
    MzInclusionRanges: List[Agilent.MassSpectrometry.MIDAC.IDoubleRange]
    MzOfInterestRanges: List[Agilent.MassSpectrometry.MIDAC.IDoubleRange]
    ScanSegmentRange: Agilent.MassSpectrometry.MIDAC.IIntRange

    def Clone(self) -> Agilent.MassSpectrometry.MIDAC.IMidacMsFilters: ...

class IMidacMsFiltersChrom(object):  # Interface
    AcqTimeRange: Agilent.MassSpectrometry.MIDAC.IDoubleRange
    ApplicableFilters: Agilent.MassSpectrometry.MIDAC.ApplicableFilters
    CompensationFieldRange: Agilent.MassSpectrometry.MIDAC.IDoubleRange
    DispersionFieldRange: Agilent.MassSpectrometry.MIDAC.IDoubleRange
    DriftTimeRanges: List[Agilent.MassSpectrometry.MIDAC.IDoubleRange]
    FragmentationClass: Agilent.MassSpectrometry.MIDAC.FragmentationClass
    FragmentationEnergyRange: Agilent.MassSpectrometry.MIDAC.IDoubleRange
    FragmentationOpMode: Agilent.MassSpectrometry.MIDAC.FragmentationOpMode
    FragmentorVoltageRange: Agilent.MassSpectrometry.MIDAC.IDoubleRange
    IonPolarity: Agilent.MassSpectrometry.MIDAC.Polarity
    IonizationMode: Agilent.MassSpectrometry.MIDAC.Ionization
    MsLevel: Agilent.MassSpectrometry.MIDAC.MsLevel
    MsScanType: Agilent.MassSpectrometry.MIDAC.MsScanType
    MsStorageMode: Agilent.MassSpectrometry.MIDAC.MsStorageMode
    MzExclusionRanges: List[Agilent.MassSpectrometry.MIDAC.IDoubleRange]
    MzInclusionRanges: List[Agilent.MassSpectrometry.MIDAC.IDoubleRange]
    MzOfInterestRanges: List[Agilent.MassSpectrometry.MIDAC.IDoubleRange]
    ScanSegmentRange: Agilent.MassSpectrometry.MIDAC.IIntRange

    def Clone(self) -> Agilent.MassSpectrometry.MIDAC.IMidacMsFiltersChrom: ...

class IMidacMsFiltersSpec(object):  # Interface
    AcqTimeRanges: List[Agilent.MassSpectrometry.MIDAC.IDoubleRange]
    ApplicableFilters: Agilent.MassSpectrometry.MIDAC.ApplicableFilters
    CompensationFieldRange: Agilent.MassSpectrometry.MIDAC.IDoubleRange
    DispersionFieldRange: Agilent.MassSpectrometry.MIDAC.IDoubleRange
    DriftTimeRanges: List[Agilent.MassSpectrometry.MIDAC.IDoubleRange]
    FragmentationClass: Agilent.MassSpectrometry.MIDAC.FragmentationClass
    FragmentationEnergyRange: Agilent.MassSpectrometry.MIDAC.IDoubleRange
    FragmentationOpMode: Agilent.MassSpectrometry.MIDAC.FragmentationOpMode
    FragmentorVoltageRange: Agilent.MassSpectrometry.MIDAC.IDoubleRange
    IonPolarity: Agilent.MassSpectrometry.MIDAC.Polarity
    IonizationMode: Agilent.MassSpectrometry.MIDAC.Ionization
    MsLevel: Agilent.MassSpectrometry.MIDAC.MsLevel
    MsScanType: Agilent.MassSpectrometry.MIDAC.MsScanType
    MsStorageMode: Agilent.MassSpectrometry.MIDAC.MsStorageMode
    MzOfInterestRanges: List[Agilent.MassSpectrometry.MIDAC.IDoubleRange]

    def Clone(self) -> Agilent.MassSpectrometry.MIDAC.IMidacMsFiltersSpec: ...

class IMidacPeakFilters(object):  # Interface
    AbsoluteThreshold: float
    MaxNumPeaks: int
    RelativeThresholdPct: float

class IMidacSpecData(object):  # Interface
    AcquiredTimeRanges: List[Agilent.MassSpectrometry.MIDAC.IDoubleRange]  # readonly
    DeviceInfo: Agilent.MassSpectrometry.MIDAC.IMidacDeviceInfo  # readonly
    IsAverage: bool  # readonly
    MaxProfilePoints: int  # readonly
    NonZeroPoints: int  # readonly
    SpectrumCount: int  # readonly
    SpectrumFormat: Agilent.MassSpectrometry.MIDAC.MidacSpecFormat  # readonly
    SpectrumType: Agilent.MassSpectrometry.MIDAC.MidacSpecType  # readonly
    XArray: List[float]  # readonly
    XSamplingPeriod: float  # readonly
    XUnit: Agilent.MassSpectrometry.MIDAC.MidacUnits  # readonly
    YArray: List[float]  # readonly

class IMidacSpecDataMs(Agilent.MassSpectrometry.MIDAC.IMidacSpecData):  # Interface
    AbundanceLimit: float  # readonly
    CompensationFieldRange: Agilent.MassSpectrometry.MIDAC.IDoubleRange  # readonly
    DispersionFieldRange: Agilent.MassSpectrometry.MIDAC.IDoubleRange  # readonly
    DriftTimeRanges: List[Agilent.MassSpectrometry.MIDAC.IDoubleRange]  # readonly
    FragmentationClass: Agilent.MassSpectrometry.MIDAC.FragmentationClass  # readonly
    FragmentationEnergyRange: Agilent.MassSpectrometry.MIDAC.IDoubleRange  # readonly
    FragmentationOpMode: Agilent.MassSpectrometry.MIDAC.FragmentationOpMode  # readonly
    FragmentorVoltageRange: Agilent.MassSpectrometry.MIDAC.IDoubleRange  # readonly
    IonPolarity: Agilent.MassSpectrometry.MIDAC.Polarity  # readonly
    IonizationMode: Agilent.MassSpectrometry.MIDAC.Ionization  # readonly
    MsLevel: Agilent.MassSpectrometry.MIDAC.MsLevel  # readonly
    MsScanType: Agilent.MassSpectrometry.MIDAC.MsScanType  # readonly
    MsStorageMode: Agilent.MassSpectrometry.MIDAC.MsStorageMode  # readonly
    MzOfInterestRanges: List[Agilent.MassSpectrometry.MIDAC.IDoubleRange]  # readonly
    ParentScanIdArray: List[int]  # readonly
    ScanId: int  # readonly

class IMidacUnitConverter(object):  # Interface
    AcqTimeRange: Agilent.MassSpectrometry.MIDAC.IDoubleRange  # readonly
    DriftBinWidth: float  # readonly
    TofBinWidth: float  # readonly
    TofMassCalA: float  # readonly
    TofMassCalTo: float  # readonly

    def SupportsConversion(
        self,
        oldUnits: Agilent.MassSpectrometry.MIDAC.MidacUnits,
        newUnits: Agilent.MassSpectrometry.MIDAC.MidacUnits,
    ) -> bool: ...
    def TofMassCalPolynomial(
        self, coefficients: List[float], tMin: float, tMax: float
    ) -> None: ...
    @overload
    def Convert(
        self,
        oldUnits: Agilent.MassSpectrometry.MIDAC.MidacUnits,
        newUnits: Agilent.MassSpectrometry.MIDAC.MidacUnits,
        value_: float,
    ) -> bool: ...
    @overload
    def Convert(
        self,
        oldUnits: Agilent.MassSpectrometry.MIDAC.MidacUnits,
        newUnits: Agilent.MassSpectrometry.MIDAC.MidacUnits,
        doubleArray: List[float],
    ) -> bool: ...
    @overload
    def Convert(
        self,
        newUnits: Agilent.MassSpectrometry.MIDAC.MidacUnits,
        doubleRange: Agilent.MassSpectrometry.MIDAC.IDoubleRange,
    ) -> bool: ...
    def Equals(
        self, other: Agilent.MassSpectrometry.MIDAC.IMidacUnitConverter
    ) -> bool: ...

class IRange(System.ICloneable):  # Interface
    Center: float  # readonly
    IsEmpty: bool  # readonly
    IsSymmetric: bool  # readonly
    IsZeroWidth: bool  # readonly
    Max: T  # readonly
    Min: T  # readonly
    Units: Agilent.MassSpectrometry.MIDAC.MidacUnits

    def Equals(self, other: Agilent.MassSpectrometry.MIDAC.IRange) -> bool: ...
    @overload
    def Contains(self, value_: T) -> bool: ...
    @overload
    def Contains(self, otherRange: Agilent.MassSpectrometry.MIDAC.IRange) -> bool: ...
    def SetMinMax(self, min: T, max: T) -> None: ...
    def ConstrainTo(
        self, constraintRange: Agilent.MassSpectrometry.MIDAC.IRange
    ) -> None: ...
    def Clear(self) -> None: ...
    def Clone(self) -> Agilent.MassSpectrometry.MIDAC.IRange: ...
    def ToString(self) -> str: ...

class IntRange(
    System.ICloneable,
    Agilent.MassSpectrometry.MIDAC.IIntRange,
    Agilent.MassSpectrometry.MIDAC.Range[int],
    Agilent.MassSpectrometry.MIDAC.IRange[int],
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, zeroWidthValue: int) -> None: ...
    @overload
    def __init__(self, min: int, max: int) -> None: ...
    @overload
    def __init__(self, src: Agilent.MassSpectrometry.MIDAC.IntRange) -> None: ...
    @staticmethod
    def EqualRanges(
        rng1: Agilent.MassSpectrometry.MIDAC.IIntRange,
        rng2: Agilent.MassSpectrometry.MIDAC.IIntRange,
    ) -> bool: ...
    @staticmethod
    def IsNullOrEmpty(range: Agilent.MassSpectrometry.MIDAC.IIntRange) -> bool: ...

class Ionization(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    Apci: Agilent.MassSpectrometry.MIDAC.Ionization = ...  # static # readonly
    Appi: Agilent.MassSpectrometry.MIDAC.Ionization = ...  # static # readonly
    CI: Agilent.MassSpectrometry.MIDAC.Ionization = ...  # static # readonly
    EI: Agilent.MassSpectrometry.MIDAC.Ionization = ...  # static # readonly
    Esi: Agilent.MassSpectrometry.MIDAC.Ionization = ...  # static # readonly
    ICP: Agilent.MassSpectrometry.MIDAC.Ionization = ...  # static # readonly
    JetStream: Agilent.MassSpectrometry.MIDAC.Ionization = ...  # static # readonly
    Maldi: Agilent.MassSpectrometry.MIDAC.Ionization = ...  # static # readonly
    Mixed: Agilent.MassSpectrometry.MIDAC.Ionization = ...  # static # readonly
    MsChip: Agilent.MassSpectrometry.MIDAC.Ionization = ...  # static # readonly
    NanoEsi: Agilent.MassSpectrometry.MIDAC.Ionization = ...  # static # readonly
    Unspecified: Agilent.MassSpectrometry.MIDAC.Ionization = ...  # static # readonly

class MidacNumericPrecisionLibrary:  # Class
    @staticmethod
    def FormatDoubleScientific(value_: float, digits: int) -> str: ...
    @staticmethod
    def FormatFloat(value_: float, digitsAfterDecimal: int) -> str: ...
    @staticmethod
    def UnitAbbrevIsSuffix(
        units: Agilent.MassSpectrometry.MIDAC.MidacUnits, unitStr: str
    ) -> bool: ...
    @staticmethod
    def DigitsAfterDecimal(units: Agilent.MassSpectrometry.MIDAC.MidacUnits) -> int: ...
    @staticmethod
    def FormatDouble(value_: float, digitsAfterDecimal: int) -> str: ...
    @staticmethod
    def SetToDefaults() -> None: ...
    @staticmethod
    def SetDigitsAfterDecimal(
        units: Agilent.MassSpectrometry.MIDAC.MidacUnits, value_: int
    ) -> None: ...

class MidacSpecFormat(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    Metadata: Agilent.MassSpectrometry.MIDAC.MidacSpecFormat = ...  # static # readonly
    Peak: Agilent.MassSpectrometry.MIDAC.MidacSpecFormat = ...  # static # readonly
    Profile: Agilent.MassSpectrometry.MIDAC.MidacSpecFormat = ...  # static # readonly
    Unspecified: Agilent.MassSpectrometry.MIDAC.MidacSpecFormat = (
        ...
    )  # static # readonly
    ZeroBounded: Agilent.MassSpectrometry.MIDAC.MidacSpecFormat = (
        ...
    )  # static # readonly
    ZeroTrimmed: Agilent.MassSpectrometry.MIDAC.MidacSpecFormat = (
        ...
    )  # static # readonly

class MidacSpecType(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    DriftSpectrum: Agilent.MassSpectrometry.MIDAC.MidacSpecType = (
        ...
    )  # static # readonly
    MassSpectrum: Agilent.MassSpectrometry.MIDAC.MidacSpecType = (
        ...
    )  # static # readonly
    MzSpectrum: Agilent.MassSpectrometry.MIDAC.MidacSpecType = ...  # static # readonly
    Unspecified: Agilent.MassSpectrometry.MIDAC.MidacSpecType = ...  # static # readonly
    UvVisSpecrum: Agilent.MassSpectrometry.MIDAC.MidacSpecType = (
        ...
    )  # static # readonly

class MidacUnits(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    AcqTimeResolution: Agilent.MassSpectrometry.MIDAC.MidacUnits = (
        ...
    )  # static # readonly
    Centigrade: Agilent.MassSpectrometry.MIDAC.MidacUnits = ...  # static # readonly
    CorrectionFactor: Agilent.MassSpectrometry.MIDAC.MidacUnits = (
        ...
    )  # static # readonly
    Counts: Agilent.MassSpectrometry.MIDAC.MidacUnits = ...  # static # readonly
    DriftBinIndex: Agilent.MassSpectrometry.MIDAC.MidacUnits = ...  # static # readonly
    DriftResolution: Agilent.MassSpectrometry.MIDAC.MidacUnits = (
        ...
    )  # static # readonly
    FlightTimeBinIndex: Agilent.MassSpectrometry.MIDAC.MidacUnits = (
        ...
    )  # static # readonly
    FrameNumber: Agilent.MassSpectrometry.MIDAC.MidacUnits = ...  # static # readonly
    Mass: Agilent.MassSpectrometry.MIDAC.MidacUnits = ...  # static # readonly
    MassResolution: Agilent.MassSpectrometry.MIDAC.MidacUnits = ...  # static # readonly
    MassToCharge: Agilent.MassSpectrometry.MIDAC.MidacUnits = ...  # static # readonly
    Milliseconds: Agilent.MassSpectrometry.MIDAC.MidacUnits = ...  # static # readonly
    Minutes: Agilent.MassSpectrometry.MIDAC.MidacUnits = ...  # static # readonly
    Mobility: Agilent.MassSpectrometry.MIDAC.MidacUnits = ...  # static # readonly
    Nanoseconds: Agilent.MassSpectrometry.MIDAC.MidacUnits = ...  # static # readonly
    Noise: Agilent.MassSpectrometry.MIDAC.MidacUnits = ...  # static # readonly
    Percent: Agilent.MassSpectrometry.MIDAC.MidacUnits = ...  # static # readonly
    Score: Agilent.MassSpectrometry.MIDAC.MidacUnits = ...  # static # readonly
    Seconds: Agilent.MassSpectrometry.MIDAC.MidacUnits = ...  # static # readonly
    SignalToNoise: Agilent.MassSpectrometry.MIDAC.MidacUnits = ...  # static # readonly
    SquareAngstrom: Agilent.MassSpectrometry.MIDAC.MidacUnits = ...  # static # readonly
    Torr: Agilent.MassSpectrometry.MIDAC.MidacUnits = ...  # static # readonly
    Unspecified: Agilent.MassSpectrometry.MIDAC.MidacUnits = ...  # static # readonly
    Volts: Agilent.MassSpectrometry.MIDAC.MidacUnits = ...  # static # readonly
    VoltsPerCm: Agilent.MassSpectrometry.MIDAC.MidacUnits = ...  # static # readonly

class MsLevel(System.IConvertible, System.IComparable, System.IFormattable):  # Struct
    All: Agilent.MassSpectrometry.MIDAC.MsLevel = ...  # static # readonly
    MS: Agilent.MassSpectrometry.MIDAC.MsLevel = ...  # static # readonly
    MSMS: Agilent.MassSpectrometry.MIDAC.MsLevel = ...  # static # readonly

class MsScanType(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    All: Agilent.MassSpectrometry.MIDAC.MsScanType = ...  # static # readonly
    AllMS: Agilent.MassSpectrometry.MIDAC.MsScanType = ...  # static # readonly
    AllMSN: Agilent.MassSpectrometry.MIDAC.MsScanType = ...  # static # readonly
    HighResolutionScan: Agilent.MassSpectrometry.MIDAC.MsScanType = (
        ...
    )  # static # readonly
    MultipleReaction: Agilent.MassSpectrometry.MIDAC.MsScanType = (
        ...
    )  # static # readonly
    NeutralGain: Agilent.MassSpectrometry.MIDAC.MsScanType = ...  # static # readonly
    NeutralLoss: Agilent.MassSpectrometry.MIDAC.MsScanType = ...  # static # readonly
    PrecursorIon: Agilent.MassSpectrometry.MIDAC.MsScanType = ...  # static # readonly
    ProductIon: Agilent.MassSpectrometry.MIDAC.MsScanType = ...  # static # readonly
    Scan: Agilent.MassSpectrometry.MIDAC.MsScanType = ...  # static # readonly
    SelectedIon: Agilent.MassSpectrometry.MIDAC.MsScanType = ...  # static # readonly
    TotalIon: Agilent.MassSpectrometry.MIDAC.MsScanType = ...  # static # readonly
    Unspecified: Agilent.MassSpectrometry.MIDAC.MsScanType = ...  # static # readonly

class MsStorageMode(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    Mixed: Agilent.MassSpectrometry.MIDAC.MsStorageMode = ...  # static # readonly
    PeakDetectedSpectrum: Agilent.MassSpectrometry.MIDAC.MsStorageMode = (
        ...
    )  # static # readonly
    ProfileSpectrum: Agilent.MassSpectrometry.MIDAC.MsStorageMode = (
        ...
    )  # static # readonly
    Unspecified: Agilent.MassSpectrometry.MIDAC.MsStorageMode = ...  # static # readonly

class Polarity(System.IConvertible, System.IComparable, System.IFormattable):  # Struct
    Mixed: Agilent.MassSpectrometry.MIDAC.Polarity = ...  # static # readonly
    Negative: Agilent.MassSpectrometry.MIDAC.Polarity = ...  # static # readonly
    Positive: Agilent.MassSpectrometry.MIDAC.Polarity = ...  # static # readonly
    Unassigned: Agilent.MassSpectrometry.MIDAC.Polarity = ...  # static # readonly

class Range(
    Generic[T], System.ICloneable, Agilent.MassSpectrometry.MIDAC.IRange[T]
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, zeroWidthValue: T) -> None: ...
    @overload
    def __init__(self, min: T, max: T) -> None: ...
    @overload
    def __init__(
        self, min: T, max: T, units: Agilent.MassSpectrometry.MIDAC.MidacUnits
    ) -> None: ...
    @overload
    def __init__(self, src: Agilent.MassSpectrometry.MIDAC.Range) -> None: ...
    def Equals(self, obj: Any) -> bool: ...
    def GetHashCode(self) -> int: ...
    def ToString(self) -> str: ...
    def Clone(self) -> Agilent.MassSpectrometry.MIDAC.Range: ...



from . import (
    ApplicationServices,
    CalibrationCurveAtAGlance,
    Controls,
    ConvertSamples,
    DynamicCalibrationSetup,
    ErrorWindow,
    HeatMap,
    PlotControl,
    PlotControl3D,
    Profile3DView,
    QuantAppServices,
    QuantWPF,
    Screening,
    SetupDesktopIconsWPF,
    Startup,
    Themes,
    ToolbarWPF,
    UIModel,
)



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import MRMOptimizer, Properties, Quant, Unknowns

# Discovered Generic TypeVars:
T = TypeVar("T")

# Stubs for namespace: Agilent.MassHunter.Quantitative.ApplicationServices

class ApplicationServiceException(
    System.Runtime.InteropServices._Exception,
    System.Runtime.Serialization.ISerializable,
    System.Exception,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, message: str) -> None: ...
    @overload
    def __init__(
        self,
        info: System.Runtime.Serialization.SerializationInfo,
        context: System.Runtime.Serialization.StreamingContext,
    ) -> None: ...
    @overload
    def __init__(self, message: str, innerException: System.Exception) -> None: ...

class Chromatogram:  # Class
    def __init__(self) -> None: ...

    XValues: List[float]
    YValues: List[float]

class Config:  # Class
    @staticmethod
    def GetTimeout() -> Optional[System.TimeSpan]: ...
    @staticmethod
    def GetSubFolder(type: str) -> str: ...
    @staticmethod
    def GetServiceClientType(type: str) -> str: ...
    @staticmethod
    def SetupTimeout(binding: System.ServiceModel.Channels.Binding) -> None: ...
    @staticmethod
    def GetServiceInstall(type: str) -> str: ...

class DataTableTransfer(
    System.IDisposable,
    Agilent.MassHunter.Quantitative.ApplicationServices.IDataTableTransfer,
):  # Class
    def __init__(self) -> None: ...
    def Initialize(
        self,
        host: System.ServiceModel.ServiceHost,
        table: System.Data.DataTable,
        pageSize: int,
    ) -> None: ...
    def Reset(self) -> None: ...
    def ReadNext(self) -> System.Data.DataTable: ...
    def GetTotalCount(self) -> int: ...
    def Dispose(self) -> None: ...

class DataTableTransferClient(
    System.ServiceModel.ClientBase[
        Agilent.MassHunter.Quantitative.ApplicationServices.IDataTableTransfer
    ],
    System.IDisposable,
    Agilent.MassHunter.Quantitative.ApplicationServices.IDataTableTransfer,
    System.ServiceModel.ICommunicationObject,
):  # Class
    def __init__(
        self,
        binding: System.ServiceModel.Channels.Binding,
        address: System.ServiceModel.EndpointAddress,
    ) -> None: ...
    def ReadNext(self) -> System.Data.DataTable: ...
    def Reset(self) -> None: ...
    def Dispose(self) -> None: ...
    def GetTotalCount(self) -> int: ...

class DataTransferClient(
    System.IDisposable,
    Generic[T],
    System.ServiceModel.ClientBase[
        Agilent.MassHunter.Quantitative.ApplicationServices.IDataTransfer[T]
    ],
    Agilent.MassHunter.Quantitative.ApplicationServices.IDataTransfer[T],
    System.ServiceModel.ICommunicationObject,
):  # Class
    def __init__(
        self,
        binding: System.ServiceModel.Channels.Binding,
        address: System.ServiceModel.EndpointAddress,
    ) -> None: ...
    def ReadNext(self) -> T: ...
    def Reset(self) -> None: ...
    def Dispose(self) -> None: ...
    def GetTotalCount(self) -> int: ...

class DataTransfer(
    Generic[T],
    System.IDisposable,
    Agilent.MassHunter.Quantitative.ApplicationServices.IDataTransfer[T],
):  # Class
    def __init__(self, list: List[T]) -> None: ...
    def ReadNext(self) -> T: ...
    def Reset(self) -> None: ...
    def Dispose(self) -> None: ...
    def GetTotalCount(self) -> int: ...

class IApplicationServiceBase(System.IDisposable):  # Interface
    CommunicationState: System.ServiceModel.CommunicationState  # readonly

    def ConnectWithCallback(self, callback: Any) -> None: ...
    def Reconnect(self) -> None: ...
    def CloseApplication(self) -> None: ...
    def Connect(self) -> None: ...

class IDataTableTransfer(System.IDisposable):  # Interface
    def ReadNext(self) -> System.Data.DataTable: ...
    def Reset(self) -> None: ...
    def GetTotalCount(self) -> int: ...

class IDataTransfer(System.IDisposable):  # Interface
    def ReadNext(self) -> T: ...
    def Reset(self) -> None: ...
    def GetTotalCount(self) -> int: ...

class ServiceFactory:  # Class
    @staticmethod
    def CreateService() -> T: ...

class ServiceFault:  # Class
    def __init__(self) -> None: ...

    InnerExceptionMessage: str
    InnerExceptionStackTrace: str
    InnerExceptionType: str
    Message: str
    Source: str
    StackTrace: str
    Type: str



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import PeakAnnotationType, SetupGraphicsContext

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.Dialogs

class OutlierCtrl(
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UserControl,
):  # Class
    def __init__(self) -> None: ...
    def Initialize(
        self, window: Agilent.MassHunter.Quantitative.UIModel.ICagWindow
    ) -> None: ...
    def Apply(self, context: SetupGraphicsContext) -> None: ...

class PaneDimensionControl(
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UserControl,
):  # Class
    def __init__(self) -> None: ...

    Columns: int  # readonly
    Rows: int  # readonly

    @staticmethod
    def CalcSize() -> System.Drawing.Size: ...

    DimensionSelected: System.EventHandler  # Event

class PaneDimensionDialogs(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self) -> None: ...

    Columns: int  # readonly
    Rows: int  # readonly

    DimensionSelected: System.EventHandler  # Event

class PeakAnnotationsDialog(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self) -> None: ...

    QualifierInfoLabelType: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.QualifierInfoLabelType
    )  # readonly
    ShowPeakAnnotationNames: bool  # readonly
    ShowPeakAnnotationUnits: bool  # readonly

    def GetPeakAnnotations(self) -> List[PeakAnnotationType]: ...
    def Initialize(
        self,
        instrument: Agilent.MassSpectrometry.DataAnalysis.Quantitative.InstrumentType,
        annotations: List[PeakAnnotationType],
        showNames: bool,
        showUnits: bool,
        qualifierInfoLabelType: Agilent.MassSpectrometry.DataAnalysis.Quantitative.QualifierInfoLabelType,
    ) -> None: ...

class SelectDataRowsCtrl(
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UserControl,
):  # Class
    def __init__(self) -> None: ...

    GroupBoxFromLabel: str
    GroupBoxToLabel: str

    def GetSelectedRows(
        self,
    ) -> List[Agilent.MassSpectrometry.DataAnalysis.Quantitative.RowIdBase]: ...
    def Initialize(
        self,
        available: Iterable[
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.RowIdBase
        ],
        shown: Iterable[Agilent.MassSpectrometry.DataAnalysis.Quantitative.RowIdBase],
    ) -> None: ...
    def InitializeColumns(
        self,
        table: System.Data.DataTable,
        instrumentType: Agilent.MassSpectrometry.DataAnalysis.Quantitative.InstrumentType,
        formats: Agilent.MassHunter.Quantitative.UIModel.INumberFormats,
        columns: List[str],
    ) -> None: ...
    def InitSort(self, defaultSortColumn: str) -> None: ...

class SetupGraphicsDialog(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(
        self, window: Agilent.MassHunter.Quantitative.UIModel.ICagWindow
    ) -> None: ...

class SetupGraphicsOrganizeCtrl(
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UserControl,
):  # Class
    def __init__(self) -> None: ...
    def Initialize(
        self, window: Agilent.MassHunter.Quantitative.UIModel.ICagWindow
    ) -> None: ...
    def Apply(self, context: SetupGraphicsContext) -> None: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Stubs for namespace: Agilent.MassSpectrometry.EventManipulating.Model

class IEventContext(System.IDisposable):  # Interface
    ControlCount: int  # readonly
    StackCount: int  # readonly
    Top: Agilent.MassSpectrometry.EventManipulating.Model.IEventManipulator  # readonly

    def RegisterControl(self, ctrl: System.Windows.Forms.Control) -> None: ...
    def RevokeControl(self, ctrl: System.Windows.Forms.Control) -> None: ...
    def Pop(
        self,
        manipulator: Agilent.MassSpectrometry.EventManipulating.Model.IEventManipulator,
    ) -> None: ...
    def Peek(
        self, index: int
    ) -> Agilent.MassSpectrometry.EventManipulating.Model.IEventManipulator: ...
    def Push(
        self,
        manipulator: Agilent.MassSpectrometry.EventManipulating.Model.IEventManipulator,
    ) -> None: ...

class IEventManipulator(System.IDisposable):  # Interface
    RubberBand: Agilent.MassSpectrometry.EventManipulating.Model.IRubberBand

    def OnMouseDown(
        self, sender: Any, e: System.Windows.Forms.MouseEventArgs
    ) -> None: ...
    def OnMouseDoubleClick(
        self, sender: Any, e: System.Windows.Forms.MouseEventArgs
    ) -> None: ...
    def OnEnd(self) -> None: ...
    def OnMouseMove(
        self, sender: Any, e: System.Windows.Forms.MouseEventArgs
    ) -> None: ...
    def OnMouseUp(
        self, sender: Any, e: System.Windows.Forms.MouseEventArgs
    ) -> None: ...
    def OnKeyDown(self, sender: Any, e: System.Windows.Forms.KeyEventArgs) -> None: ...
    def OnMouseWheel(
        self, sender: Any, e: System.Windows.Forms.MouseEventArgs
    ) -> None: ...
    def OnStart(self) -> None: ...
    def OnResume(self) -> None: ...
    def OnKeyUp(self, sender: Any, e: System.Windows.Forms.KeyEventArgs) -> None: ...
    def OnDoubleClick(self, sender: Any, e: System.EventArgs) -> None: ...
    def OnSuspend(self) -> None: ...

class IRubberBand(System.IDisposable):  # Interface
    def Erase(self) -> None: ...
    def MoveTo(
        self, ctrl: System.Windows.Forms.Control, position: System.Drawing.Point
    ) -> None: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import Chromatogram, IApplicationServiceBase, IDataTableTransfer

# Stubs for namespace: Agilent.MassHunter.Quantitative.ApplicationServices.Unknowns

class IUnknownsAnalysis(IApplicationServiceBase, System.IDisposable):  # Interface
    def AnalyzeAll(self) -> None: ...
    def GetHits(
        self,
        batchId: int,
        sampleId: int,
        deconvolutionMethodId: Optional[int],
        componentId: Optional[int],
        hitId: Optional[int],
    ) -> IDataTableTransfer: ...
    def GetIonPeak(
        self,
        batchId: int,
        sampleId: int,
        deconvolutionMethodId: Optional[int],
        componentId: Optional[int],
        ionPeakId: Optional[int],
    ) -> IDataTableTransfer: ...
    def GetTargetMatchMethod(
        self, batchID: int, sampleID: int, targetMatchMethodID: Optional[int]
    ) -> IDataTableTransfer: ...
    def GetLibrarySearchMethod(
        self,
        batchID: int,
        sampleID: int,
        identificationMethodID: Optional[int],
        librarySearchMethodID: Optional[int],
    ) -> IDataTableTransfer: ...
    def LoadMethodToAllSamples(self, method: str) -> None: ...
    def GetComponents(
        self,
        batchId: int,
        sampleId: int,
        deconvolutionMethodId: Optional[int],
        componentId: Optional[int],
    ) -> IDataTableTransfer: ...
    def GetIdentificationMethod(
        self, batchID: int, sampleID: int, identificationMethodID: Optional[int]
    ) -> IDataTableTransfer: ...
    def GetSamples(
        self, batchId: Optional[int], sampleId: Optional[int]
    ) -> IDataTableTransfer: ...
    def AddSamples(self, sampleFileNames: List[str]) -> None: ...
    def GetTIC(
        self, batchID: int, sampleID: int, scan: str, ionPolarity: str
    ) -> Chromatogram: ...
    def CreateAnlaysis(self, batchFolder: str, analysisName: str) -> None: ...
    def GetDeconvolutionMethod(
        self, batchId: int, sampleId: int, deconvolutionMethodId: Optional[int]
    ) -> IDataTableTransfer: ...

class IUnknownsAnalysisCallback(object):  # Interface
    def AnalysisProgressChanged(
        self,
        batchId: int,
        sampleId: int,
        analysisType: str,
        currentStep: int,
        totalSteps: int,
    ) -> None: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.Quantitative.QuantConsole

class CommandLine:  # Class
    def __init__(self) -> None: ...

    AccountName: str
    ConnectionTicket: str
    ConsoleTrace: bool
    Culture: str
    DefineConstants: List[str]
    Domain: str
    EncryptedPassword: str
    ErrorHasUserWhileNotRequired: bool
    Help: bool
    Instrument: str
    NoLogo: bool
    ParametersXml: str
    Password: str
    ScriptFiles: List[str]
    Server: str
    Silent: bool
    User: str

    def Run(self) -> int: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from .Compliance import ComplianceConfiguration, ICompliance

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ComplianceUI

class FileAndFolderFilter:  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(
        self,
        name: str,
        items: List[
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.ComplianceUI.FileAndFolderFilterItem
        ],
    ) -> None: ...

    FilterItems: List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ComplianceUI.FileAndFolderFilterItem
    ]
    Name: str

class FileAndFolderFilterItem:  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, isFolder: bool, extensions: List[str]) -> None: ...

    Extensions: List[str]
    IsFolder: bool

class FileDialogMode(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    New: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ComplianceUI.FileDialogMode
    ) = ...  # static # readonly
    Open: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ComplianceUI.FileDialogMode
    ) = ...  # static # readonly
    SaveAs: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ComplianceUI.FileDialogMode
    ) = ...  # static # readonly

class IBatchDialog(System.IDisposable):  # Interface
    AllowFileRevisions: bool
    AuditTrail: bool
    BatchFile: str  # readonly
    BatchFolder: str  # readonly
    FileDialogMode: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ComplianceUI.FileDialogMode
    )  # readonly
    InitialFolder: str
    ReadOnly: bool  # readonly
    RevisionNumber: str  # readonly
    Title: str

    def ShowDialog(
        self, parent: System.Windows.Forms.IWin32Window
    ) -> System.Windows.Forms.DialogResult: ...

class IComplianceConfigurationEdit(System.IDisposable):  # Interface
    CanEditRoles: bool  # readonly

    def Save(self, config: ComplianceConfiguration) -> None: ...
    def Load(self) -> ComplianceConfiguration: ...
    def ResetToDefault(self) -> ComplianceConfiguration: ...
    def PreprocessNewRoleName(self, roleName: str) -> str: ...
    def GetAvailableRoles(self) -> List[str]: ...
    def Run(self, args: List[str]) -> None: ...

class IComplianceUI(object):  # Interface
    Compliance: ICompliance  # readonly

    def CreateComplianceConfigurationEdit(
        self,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ComplianceUI.IComplianceConfigurationEdit
    ): ...
    def CreateFileAndFolderDialog(
        self,
        mode: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ComplianceUI.FileDialogMode,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ComplianceUI.IFileAndFolderDialog
    ): ...
    def CreateLibraryDialog(
        self,
        mode: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ComplianceUI.FileDialogMode,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ComplianceUI.ILibraryDialog
    ): ...
    def CreateSampleFileDialog(
        self,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ComplianceUI.ISampleFileDialog
    ): ...
    def CreateMethodDialog(
        self,
        mode: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ComplianceUI.FileDialogMode,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ComplianceUI.IMethodDialog
    ): ...
    def CreateUnknownsFileDialog(
        self,
        mode: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ComplianceUI.FileDialogMode,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ComplianceUI.IUnknownsFileDialog
    ): ...
    def CreateFileDialog(
        self,
        mode: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ComplianceUI.FileDialogMode,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ComplianceUI.IFileDialog
    ): ...
    def CreateLogonDialog(
        self,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ComplianceUI.ILogonDialog
    ): ...
    def CreateFolderDialog(
        self,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ComplianceUI.IFolderDialog
    ): ...
    def CreateBatchDialog(
        self,
        mode: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ComplianceUI.FileDialogMode,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ComplianceUI.IBatchDialog
    ): ...

class IFileAndFolderDialog(System.IDisposable):  # Interface
    Filters: List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ComplianceUI.FileAndFolderFilter
    ]
    InitialFolder: str
    Mode: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ComplianceUI.FileDialogMode
    )  # readonly
    PathName: str  # readonly
    Title: str

    def ShowDialog(
        self, parent: System.Windows.Forms.IWin32Window
    ) -> System.Windows.Forms.DialogResult: ...

class IFileDialog(System.IDisposable):  # Interface
    DefaultExtension: str
    DefaultFileName: str
    FileMustExists: bool
    Filters: str
    InitialFolder: str
    Mode: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ComplianceUI.FileDialogMode
    )  # readonly
    MultiSelect: bool
    OverwritePrompt: bool
    PathName: str  # readonly
    PathNames: List[str]  # readonly
    Title: str

    def ShowDialog(
        self, parent: System.Windows.Forms.IWin32Window
    ) -> System.Windows.Forms.DialogResult: ...

class IFolderDialog(System.IDisposable):  # Interface
    InitialFolder: str
    PathName: str  # readonly
    Title: str

    def ShowDialog(
        self, parent: System.Windows.Forms.IWin32Window
    ) -> System.Windows.Forms.DialogResult: ...

class ILibraryDialog(System.IDisposable):  # Interface
    AllowFileRevisions: bool
    AllowNistLibraries: bool
    ExtraFileFilter: str
    InitialFolder: str
    Mode: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ComplianceUI.FileDialogMode
    )  # readonly
    PathName: str  # readonly
    RevisionNumber: str  # readonly
    Title: str

    def AllowReferenceLibrary(self) -> None: ...
    def ShowDialog(
        self, parent: System.Windows.Forms.IWin32Window
    ) -> System.Windows.Forms.DialogResult: ...

class ILogonDialog(System.IDisposable):  # Interface
    Compliance: ICompliance  # readonly
    Domain: str
    Handle: System.IntPtr  # readonly
    LogonXml: str  # readonly
    Message: str
    Password: System.Security.SecureString  # readonly
    Server: str
    User: str
    ValidationMode: bool

    def ShowDialog(
        self, parent: System.Windows.Forms.IWin32Window
    ) -> System.Windows.Forms.DialogResult: ...

    Cancel: System.ComponentModel.CancelEventHandler  # Event
    Logon: System.ComponentModel.CancelEventHandler  # Event

class IMethodDialog(System.IDisposable):  # Interface
    AllowFileRevisions: bool
    FileDialogMode: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ComplianceUI.FileDialogMode
    )  # readonly
    FileMustNotExist: bool
    IndividualFileExtensions: List[str]
    InitialFolder: str
    PathName: str  # readonly
    RevisionNumber: str  # readonly
    Title: str

    def ShowDialog(
        self, parent: System.Windows.Forms.IWin32Window
    ) -> System.Windows.Forms.DialogResult: ...

    SaveAsFolder: System.ComponentModel.CancelEventHandler  # Event

class ISampleFileDialog(System.IDisposable):  # Interface
    InitialFolder: str
    MultiSelect: bool
    PathName: str  # readonly
    PathNames: List[str]  # readonly
    Title: str

    def ShowDialog(
        self, parent: System.Windows.Forms.IWin32Window
    ) -> System.Windows.Forms.DialogResult: ...

class IUnknownsFileDialog(System.IDisposable):  # Interface
    AllowFileRevisions: bool
    AnalysisFile: str  # readonly
    AuditTrail: bool
    BatchFolder: str  # readonly
    FileDialogMode: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ComplianceUI.FileDialogMode
    )  # readonly
    InitialFolder: str
    ReadOnly: bool  # readonly
    RevisionNumber: str  # readonly
    Title: str

    def ShowDialog(
        self, parent: System.Windows.Forms.IWin32Window
    ) -> System.Windows.Forms.DialogResult: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Controls.Dialogs

class CalcMonoisotopicMassDialog(
    System.Windows.Forms.Layout.IArrangedElement,
    Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Controls.Dialogs.IChooseSpecies,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.IWin32Window,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
):  # Class
    def __init__(
        self,
        uiState: Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.ScriptIf.IUIState,
    ) -> None: ...

class ColumnsDialog(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self, grid: System.Windows.Forms.DataGridView) -> None: ...

class ConvertLibrary(
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Window,
    System.Windows.Markup.IHaveResources,
    System.Windows.Markup.IAddChild,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Markup.IComponentConnector,
    System.Windows.IWindowService,
    System.Windows.IInputElement,
    System.Windows.IFrameworkInputElement,
    System.ComponentModel.ISupportInitialize,
):  # Class
    def __init__(self) -> None: ...

    ConversionType: Optional[
        Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.ConversionType
    ]  # readonly

    def InitializeComponent(self) -> None: ...

class ConvertLibraryL(
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Window,
    System.Windows.Markup.IHaveResources,
    System.Windows.Markup.IAddChild,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Markup.IComponentConnector,
    System.Windows.IWindowService,
    System.Windows.IInputElement,
    System.Windows.IFrameworkInputElement,
    System.ComponentModel.ISupportInitialize,
):  # Class
    def __init__(
        self,
        uiState: Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.ScriptIf.IUIState,
        type: Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.DataAccess.SuggestedConversionType,
    ) -> None: ...
    def InitializeComponent(self) -> None: ...

class ConvertLibraryXml(
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Window,
    System.Windows.Markup.IHaveResources,
    System.Windows.Markup.IAddChild,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Markup.IComponentConnector,
    System.Windows.IWindowService,
    System.Windows.IInputElement,
    System.Windows.IFrameworkInputElement,
    System.ComponentModel.ISupportInitialize,
):  # Class
    def __init__(
        self,
        uiState: Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.ScriptIf.IUIState,
        save: bool,
    ) -> None: ...
    def InitializeComponent(self) -> None: ...

class FilterPeaksDialog(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(
        self,
        uiState: Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.ScriptIf.IUIState,
    ) -> None: ...

class IChooseSpecies(System.Windows.Forms.IWin32Window):  # Interface
    AvailableSpecies: str
    ButtonAddSpecies: System.Windows.Forms.Button  # readonly
    ButtonDeleteSpecies: System.Windows.Forms.Button  # readonly
    ButtonOk: System.Windows.Forms.Button  # readonly
    ListBox: System.Windows.Forms.ListBox  # readonly
    TextBoxSpecies: System.Windows.Forms.TextBox  # readonly
    UsedSpecies: str

class LibraryProperties(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(
        self, uiContext: Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.UIContext
    ) -> None: ...

class ProgressDialog(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self) -> None: ...

    Argument: Any
    CancelButtonVisible: bool
    CancellationPending: bool  # readonly
    Error: System.Exception  # readonly
    Marquee: bool
    Message: str
    ProgressMaximum: int
    ProgressStep: int
    ProgressValue: int

    def HandleError(self, parent: System.Windows.Forms.IWin32Window) -> None: ...
    def ReportProgress(self, percent: int, state: Any) -> None: ...
    def Cancel(self) -> None: ...

    CancelButtonClick: System.EventHandler  # Event
    DoWork: System.ComponentModel.DoWorkEventHandler  # Event
    ProgressChanged: System.ComponentModel.ProgressChangedEventHandler  # Event

class RTRIConvertXmlDialog(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(
        self,
        context: Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.AppContext,
    ) -> None: ...

class SearchDialog(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(
        self, context: Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.UIContext
    ) -> None: ...

class SynthesizeSpectraDialog(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(
        self,
        uiState: Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.ScriptIf.IUIState,
    ) -> None: ...
